/*
 * Copyright (C), 2000-2002 by Contributors to the monit codebase. 
 * All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef SSL_H
#define SSL_H

#include <config.h>

#include <openssl/crypto.h>
#include <openssl/x509.h>
#include <openssl/pem.h>
#include <openssl/ssl.h>
#include <openssl/err.h>

#include "monitor.h"

typedef struct my_ssl_connection {

  int           socket;
  int           server_socket;

  SSL*          handler;
  SSL_CTX *     ctx;
  X509 *        cert;
  SSL_METHOD *  method;

  const char * cipher;
  char *        cert_subject;
  char *        cert_issuer;

} ssl_connection;

ssl_connection * new_ssl_connection();
ssl_connection * create_ssl_socket(char *, int, int);
ssl_connection * embed_ssl_socket (int);

ssl_connection * init_ssl_server (char *);
ssl_connection * create_ssl_server_socket(char *, int, int, char *);
int embed_accepted_ssl_socket(ssl_connection *, int);

int accept_ssl_socket(ssl_connection *);
int embed_accepted_ssl_socket(ssl_connection *, int);

int close_ssl_socket(ssl_connection *);
int close_ssl_server_socket(ssl_connection *);
void cleanup_ssl_socket(ssl_connection *);
int ssl_send(ssl_connection *, void *, int);
int ssl_recv(ssl_connection *, void *, int);

#endif
